@@ -10,16 +10,16 @@
 #
 # BODY: Text that will be appended to the original comment body.
 
-set -e
+set -e -E -u -o pipefail
 
 if [ -z "$GITHUB_ACTIONS" ]; then
   echo "Must be run inside GitHub Actions CI"
-  exit -1
+  exit 1
 fi
 
 if [ $# -ne 2 ]; then
   echo "Usage: $0 <COMMENT_ID> <BODY>"
-  exit -1
+  exit 1
 fi
 
 comment_id=$1
